@@ -126,10 +126,22 @@ enum {
 	STATE_ERROR = 64,
 };
 
-static const char *defTabooExts[] = { ".rpmsave", ".rpmorig", "~", ",v",
-    ".disabled", ".dpkg-old", ".dpkg-dist", ".dpkg-new", ".cfsaved",
-    ".ucf-old", ".ucf-dist", ".ucf-new",
-    ".rpmnew", ".swp", ".cfsaved", ".rhn-cfg-tmp-*"
+static const char *defTabooExts[] = {
+	",v",
+	".cfsaved",
+	".disabled",
+	".dpkg-dist",
+	".dpkg-new",
+	".dpkg-old",
+	".rhn-cfg-tmp-*",
+	".rpmnew",
+	".rpmorig",
+	".rpmsave",
+	".swp",
+	".ucf-dist",
+	".ucf-new",
+	".ucf-old",
+	"~"
 };
 static int defTabooCount = sizeof(defTabooExts) / sizeof(char *);
 
@@ -1433,13 +1445,6 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
 						RAISE_ERROR();
 					}
 
-					if (access(newlog->compress_prog, X_OK)) {
-						message(MESS_ERROR,
-							"%s:%d compression program %s is not an executable file\n",
-							configFile, lineNum, newlog->compress_prog);
-						RAISE_ERROR();
-					}
-
 					message(MESS_DEBUG, "compress_prog is now %s\n",
 						newlog->compress_prog);
 
@@ -1465,13 +1470,6 @@ static int readConfigFile(const char *configFile, struct logInfo *defConfig)
 						RAISE_ERROR();
 					}
 
-					if (access(newlog->uncompress_prog, X_OK)) {
-						message(MESS_ERROR,
-							"%s:%d uncompression program %s is not an executable file\n",
-							configFile, lineNum, newlog->uncompress_prog);
-						RAISE_ERROR();
-					}
-
 					message(MESS_DEBUG, "uncompress_prog is now %s\n",
 						newlog->uncompress_prog);
 
