@@ -5,7 +5,10 @@
 #include "queue.h"
 #include <glob.h>
 
-#include "config.h"
+/* needed for basename() on OS X */
+#if HAVE_LIBGEN_H
+#   include <libgen.h>
+#endif
 
 #define LOG_FLAG_COMPRESS	(1 << 0)
 #define LOG_FLAG_CREATE		(1 << 1)
@@ -45,15 +48,18 @@ struct logInfo {
     char *oldDir;
     enum { ROT_HOURLY, ROT_DAYS, ROT_WEEKLY, ROT_MONTHLY, ROT_YEARLY, ROT_SIZE
             } criterium;
-    unsigned long long threshhold;
-	unsigned long long maxsize;
-    unsigned long long minsize;
+    int weekday; /* used by ROT_WEEKLY only */
+    off_t threshhold;
+    off_t maxsize;
+    off_t minsize;
     int rotateCount;
+    int rotateMinAge;
     int rotateAge;
     int logStart;
     char *pre, *post, *first, *last, *preremove;
     char *logAddress;
     char *extension;
+    char *addextension;
     char *compress_prog;
     char *uncompress_prog;
     char *compress_ext;
@@ -79,6 +85,8 @@ TAILQ_HEAD(logInfoHead, logInfo) logs;
 extern int numLogs;
 extern int debug;
 
+int switch_user(uid_t user, gid_t group);
+int switch_user_back(void);
 int readAllConfigPaths(const char **paths);
 #if !defined(asprintf) && !defined(_FORTIFY_SOURCE)
 int asprintf(char **string_ptr, const char *format, ...);
